'use strict';

/* App Module */

angular.module('app', [
    'ui.bootstrap',
    'ui.router',
    'LocalStorageModule',
    'ngMaterial',
    'md.data.table',
    'sasrio.angular-material-sidenav',
    'pascalprecht.translate',
    'angular-busy',
    'luticate2Utils',
    'SignalR',
    // 'luticateAuth',
    'appSdk'
])
    .config(['$stateProvider', '$urlRouterProvider', 'ssSideNavSectionsProvider', '$mdThemingProvider', '$mdIconProvider', '$translateProvider',
        function($stateProvider, $urlRouterProvider, ssSideNavSectionsProvider, $mdThemingProvider, $mdIconProvider, $translateProvider) {

            // $mdThemingProvider
            //     .theme('default')
            //     .primaryPalette('blue', {
            //         'default': '700'
            //     });

            // $mdThemingProvider.theme('default')
            //     .primaryPalette('blue')
            //     .accentPalette('pink');

            $translateProvider.useSanitizeValueStrategy('escape');
            $translateProvider.useMessageFormatInterpolation();
            $translateProvider.useStaticFilesLoader({
                prefix: 'translations/',
                suffix: '.json'
            });
            $translateProvider.preferredLanguage('en');

            $mdIconProvider
                .icon('md-toggle-arrow', 'img/arrow.svg');

            ssSideNavSectionsProvider.initWithTheme($mdThemingProvider);
            ssSideNavSectionsProvider.initWithSections([{
                id: 'toogle_1',
                name: 'home.name',
                type: 'heading',
                children: [{
                    name: 'home.name',
                    type: 'toggle',
                    pages: [{
                        id: 'toogle_1_link_1',
                        name: 'home.name',
                        state: 'home'
                    }, {
                        id: 'toogle_1_link_2',
                        name: 'Home 1 2',
                        state: 'home.1.2',
                        hidden: true
                    }, {
                        id: 'toogle_1_link_3',
                        name: 'home.name',
                        state: 'home.1.3'
                    }]
                }]
            }, {
                id: 'link_1',
                name: 'home.name',
                state: 'home.2',
                type: 'link',
                icon: 'fa fa-check'
            }, {
                id: 'link_2',
                name: 'home.name',
                state: 'home.3',
                type: 'link'
            }, {
                id: 'link_3',
                name: 'home.name',
                state: 'common.link3',
                type: 'link',
                hidden: true
            },  {
                id: 'toogle_2',
                name: 'pkguid.name',
                type: 'heading',
                children: [{
                    name: 'pkguid.name',
                    type: 'toggle',
                    pages: [{
                        id: 'toogle_2_link_1',
                        name: 'common.all',
                        state: 'pkguid'
                    },{
                        id: 'toogle_2_link_1',
                        name: 'common.new',
                        state: 'pkguid_add'
                    }]
                }]
            }]);

            $stateProvider.state('root', {
                abstract: true,
                template: '<div ui-view=""></div>',
                // resolve: ['luticateAuthUsers', function(luticateAuthUsers)
                // {
                //     return luticateAuthUsers.loadUserData(null);
                // }]
            });

            $stateProvider.state('home', {
                url:'/',
                parent: 'root',
                title: "home.name",
                reloadOnSearch: false,
                templateUrl:'views/home.html',
                controller:'HomeController'
            });

            $stateProvider.state('pkguid', {
                url:'/pkguids',
                parent: 'root',
                title: "pkguid.name",
                reloadOnSearch: false,
                templateUrl:'views/pkguid.html',
                controller:'PkGuidController'
            });

            $stateProvider.state('pkguid_add', {
                url:'/pkguids/add',
                parent: 'root',
                title: "pkguid.add.defaultTitle",
                toolbarTitle: "pkguid.add.defaultToolbarTitle",
                reloadOnSearch: false,
                templateUrl:'views/pkguidedit.html',
                controller:'PkGuidEditController',
                params: {
                    pkguid: null
                }
            });

            $stateProvider.state('pkguid_edit', {
                url:'/pkguids/edit/:id',
                parent: 'root',
                title: "pkguid.edit.defaultTitle",
                toolbarTitle: "pkguid.edit.defaultToolbarTitle",
                reloadOnSearch: false,
                templateUrl:'views/pkguidedit.html',
                controller:'PkGuidEditController',
                params: {
                    pkguid: null
                }
            });

            $urlRouterProvider.otherwise('/');
    }])
    .run(['$rootScope', '$transitions', 'AppUtilsBusiness', 'ssSideNav', '$translate', 'luRequest', '$mdDialog', 'luNotificationsBusiness', '$mdToast', '$state',
        function ($rootScope, $transitions, AppUtilsBusiness, ssSideNav, $translate, luRequest, $mdDialog, luNotificationsBusiness, $mdToast, $state) {

        AppUtilsBusiness.addApiVersionChangedCallback(function(oldVersion, newVersion) {
            $mdDialog.show(
                $mdDialog.alert()
                    .title(AppUtilsBusiness.tr('common.updateDetected.title'))
                    .textContent(AppUtilsBusiness.tr('common.updateDetected.text',
                        {oldVersion: oldVersion, newVersion: newVersion}))
                    .ok(AppUtilsBusiness.tr('common.ok')));
        });

        luNotificationsBusiness.init();

        luNotificationsBusiness.addEventCrudCallback('pkguid', function(eventName, entityType, oldEntity, newEntity)
        {
            var text = null;
            if (eventName == luNotificationsBusiness.EVENT_CREATE) {
                text = AppUtilsBusiness.tr('pkguid.notifications.create', {text: newEntity.someText});
            }
            else if (eventName == luNotificationsBusiness.EVENT_UPDATE) {
                text = AppUtilsBusiness.tr('pkguid.notifications.update', {text: newEntity.someText});
            }
            else if (eventName == luNotificationsBusiness.EVENT_DELETE) {
                text = AppUtilsBusiness.tr('pkguid.notifications.delete', {text: oldEntity.someText});
            }
            var toast = $mdToast.simple()
                .textContent(text)
                .action(eventName == luNotificationsBusiness.EVENT_DELETE ? AppUtilsBusiness.tr('common.undo') : AppUtilsBusiness.tr('common.view'))
                .highlightAction(true)
                .highlightClass('md-accent')
                .position('bottom right');

            $mdToast.show(toast).then(function(response) {
                if (response == 'ok') {
                    if (eventName == luNotificationsBusiness.EVENT_DELETE) {
                        oldEntity.id = null;
                        $state.go('pkguid_add', {pkguid: oldEntity});
                    }
                    else {
                        $state.go('pkguid_edit', {id: newEntity.id, pkguid: newEntity});
                    }
                }
            });
        });

        // luNotificationsBusiness.addEventDeleteCallback('pkguid', function(eventName, entityType, oldEntity)
        // {
        //     var toast = $mdToast.simple()
        //         .textContent("PkGuid \'" + oldEntity.someText + "\' was deleted")
        //         .action("Undo")
        //         .highlightAction(true)
        //         .highlightClass('md-accent')
        //         .position('bottom right');
        //
        //     $mdToast.show(toast).then(function(response) {
        //         if (response == 'ok') {
        //             oldEntity.id = null;
        //             $state.go('pkguid_add', {pkguid: oldEntity});
        //         }
        //     });
        // });
        //
        // luNotificationsBusiness.addEventCreateCallback('pkguid', function(eventName, entityType, oldEntity, newEntity)
        // {
        //     var toast = $mdToast.simple()
        //         .textContent("PkGuid \'" + newEntity.someText + "\' was added")
        //         .action("View")
        //         .highlightAction(true)
        //         .highlightClass('md-accent')
        //         .position('bottom right');
        //
        //     $mdToast.show(toast).then(function(response) {
        //         if (response == 'ok') {
        //             $state.go('pkguid_edit', {id: newEntity.id, pkguid: newEntity});
        //         }
        //     });
        // });

        $translate('common.appName').then(function() {
            for (var i = 0; i < ssSideNav.sections.length; ++i) {
                var a = ssSideNav.sections[i];
                a.name = AppUtilsBusiness.tr(a.name);
                if (a.children != null) {
                    for (var j = 0; j < a.children.length; ++j) {
                        var b = a.children[j];
                        b.name = AppUtilsBusiness.tr(b.name);
                        if (b.pages != null) {
                            for (var k = 0; k < b.pages.length; ++k) {
                                var c = b.pages[k];
                                c.name = AppUtilsBusiness.tr(c.name);
                            }
                        }
                    }
                }
            }
        }, function (error) {
            console.error(error);
        });

        $transitions.onEnter({}, function($transitions)
        {
            var toState = $transitions.$to();
            var title = toState.title != null ? toState.title : toState.toolbarTitle != null ? toState.toolbarTitle : null;
            var toolbarTitle = toState.toolbarTitle != null ? toState.toolbarTitle : toState.title != null ? toState.title : null;
            if (title != null) {
                AppUtilsBusiness.setTitle(AppUtilsBusiness.tr(title));
            }
            if (toolbarTitle != null) {
                AppUtilsBusiness.setToolbarTitle(AppUtilsBusiness.tr(toolbarTitle));
            }
        });
    }]);